import React from "react";
import PropTypes from "prop-types";
import {
  Accordion,
  AccordionSummary,
  AccordionDetails,
  Grid
} from "@material-ui/core";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import withStyles from "@material-ui/core/styles/withStyles";
import MachineLog from "./common/MachineLog";
import { DataLabel } from "../../../components/common";

const IconLeftAccordionSummary = withStyles({
  expandIcon: {
    order: -1
  }
})(AccordionSummary);

const MachineAccordion = ({ machine, logs }) => {
  return (
    <Accordion>
      <IconLeftAccordionSummary
        expandIcon={<ExpandMoreIcon />}
        aria-label="Expand"
        aria-controls="additional-actions1-content"
        id="additional-actions1-header"
        IconButtonProps={{ edge: "start" }}
      >
        <Grid container>
          <Grid item xs={12} md={6}>
            <DataLabel
              label={"Full machine name"}
              data={machine.fullMachineName}
            />
          </Grid>
        </Grid>
      </IconLeftAccordionSummary>
      <AccordionDetails>
        <MachineLog logs={logs} />
      </AccordionDetails>
    </Accordion>
  );
};

MachineAccordion.propTypes = {
  machine: PropTypes.object.isRequired,
  logs: PropTypes.array.isRequired
};

export default MachineAccordion;
